@@ -1,12 +1,12 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-19'; # DATE
-our $VERSION = '0.97'; # VERSION
+our $DATE = '2015-03-20'; # DATE
+our $VERSION = '0.98'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 # this class can actually be a role instead of base class for pericmd &
 # pericmd-lite, but Mo is more lightweight than Role::Tiny (also R::T doesn't
@@ -184,6 +184,8 @@ _
 
     config_path => {
         getopt  => 'config-path=s@',
+        schema  => ['array*', of => 'str*'],
+        'x.schema.element_entity' => 'filename',
         summary => 'Set path to configuration file',
         handler => sub {
             my ($go, $val, $r) = @_;
@@ -1180,7 +1182,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.97 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-19.
+This document describes version 0.98 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-20.
 
 =head1 DESCRIPTION
 
