@@ -1,12 +1,12 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-03-19'; # DATE
-our $VERSION = '0.97'; # VERSION
+our $DATE = '2015-03-20'; # DATE
+our $VERSION = '0.98'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
 # use warnings; # already enabled by Mo
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Mo qw(build default);
 #use Moo;
@@ -506,7 +506,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.97 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-19.
+This document describes version 0.98 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-20.
 
 =head1 SYNOPSIS
 
